@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.03';
+$VERSION = '5.04';
 
 =head1 NAME
 
@@ -77,6 +77,7 @@ use Labyrinth::Audit;
 use Labyrinth::Constraints;
 use Labyrinth::Constraints::Emails;
 use Labyrinth::DBUtils;
+use Labyrinth::DIUtils;
 use Labyrinth::Variables;
 use Labyrinth::Writer;
 
@@ -218,6 +219,9 @@ sub LoadSettings {
         $settings{$key} = File::Spec->rel2abs( $settings{$key} ) ;
     }
 
+    # set image processing driver, if specified
+    Labyrinth::DIUtils::Tool($settings{diutils})    if($settings{diutils});
+
     $settings{settingsloaded} = 1;
 }
 
@@ -535,6 +539,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
